﻿using System;
using System.Drawing;
using System.IO;

using DevExpress.Utils.Drawing;
using DevExpress.XtraBars.Ribbon;
using DevExpress.XtraBars.Ribbon.Gallery;
using DevExpress.XtraEditors;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            GalleryControlGallery gallery = this.galleryControl.Gallery;

            gallery.ItemImageLayout  = ImageLayoutMode.ZoomInside;
            gallery.ItemCheckMode    = ItemCheckMode.Multiple;
            gallery.ImageSize        = new Size(200, 200);
            gallery.ShowGroupCaption = false;

            GalleryItemGroup group = new GalleryItemGroup();

            gallery.Groups.Add(group);

            Load                       += Form_Load;
            gallery.ItemClick          += gallery_ItemClick;
            gallery.ItemCheckedChanged += gallery_ItemCheckedChanged;
        }


        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            GalleryControlGallery gallery = this.galleryControl.Gallery;

            string[] filePathArray = Directory.GetFiles("IMAGE", "*.jpg");

            gallery.Groups[0].Items.Clear();

            foreach(string filePath in filePathArray)
            {
                Image image = Image.FromFile(filePath);

                FileInfo fileInfo = new FileInfo(filePath);

                GalleryItem galleryItem = new GalleryItem();

                galleryItem.Description = fileInfo.Name;
                galleryItem.Value       = fileInfo.Length;
                galleryItem.Image       = image;
                galleryItem.Tag         = filePath;

                gallery.Groups[0].Items.Add(galleryItem);
            }

            gallery.SetItemCheck(gallery.Groups[0].Items[0], true);
        }

        #endregion
        #region 갤러리 항목 클릭시 처리하기 - gallery_ItemClick(sender, e)

        /// <summary>
        /// 갤러리 항목 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gallery_ItemClick(object sender, GalleryItemClickEventArgs e)
        {
            this.pictureEdit.Image = e.Item.Image;
        }

        #endregion
        #region 갤러리 항목 체크 변경시 처리하기 - gallery_ItemCheckedChanged(sender, e)

        /// <summary>
        /// 갤러리 항목 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gallery_ItemCheckedChanged(object sender, GalleryItemEventArgs e)
        {
            this.pictureEdit.Image = e.Item.Image;
        }

        #endregion
    }
}